@@ -18,8 +18,8 @@
 //!     .expect("obtained cargo-guppy's PackageGraph");
 //!
 //! // The second argument to HakariBuilder::new specifies a Hakari (workspace-hack) package. For
-//! // the cargo-guppy repository it is called "workspace-hack".
-//! let hakari_package = package_graph.workspace().member_by_name("workspace-hack").unwrap().id();
+//! // the cargo-guppy repository it is called "guppy-workspace-hack".
+//! let hakari_package = package_graph.workspace().member_by_name("guppy-workspace-hack").unwrap().id();
 //! let hakari_builder = HakariBuilder::new(&package_graph, Some(hakari_package))
 //!     .expect("HakariBuilder was constructed");
 //!
@@ -126,6 +126,7 @@ mod cargo_toml;
 #[cfg(feature = "cli-support")]
 pub mod cli_ops;
 mod hakari;
+mod helpers;
 #[cfg(feature = "proptest1")]
 mod proptest_helpers;
 #[cfg(feature = "cli-support")]
@@ -135,7 +136,7 @@ pub mod verify;
 
 pub use crate::{
     cargo_toml::*,
-    hakari::{Hakari, HakariBuilder, UnifyTargetHost},
+    hakari::{DepFormatVersion, Hakari, HakariBuilder, UnifyTargetHost},
     toml_out::*,
 };
 
